hash stringlengths 40 40 | diff stringlengths 131 114k | message stringlengths 7 980 | project stringlengths 5 67 | split stringclasses 1
value |
|---|---|---|---|---|
337dc5e80f7d7527ac3540dffb1be539a6e38a24 | diff --git a/tests/test_api.py b/tests/test_api.py
index <HASH>..<HASH> 100644
--- a/tests/test_api.py
+++ b/tests/test_api.py
@@ -35,7 +35,7 @@ def slackwebhook_kwargs():
def twilio_kwargs():
return {'acct_sid': 'your sid', 'auth_token': 'your token',
'from_': '+19998675309', 'to': '+19998675309', '... | fixes twilio for kwargs to adjust for interface change | trp07_messages | train |
38735bfaa9fc7388bf7cb9fd4bda3ff078ea420a | diff --git a/src/Config.php b/src/Config.php
index <HASH>..<HASH> 100644
--- a/src/Config.php
+++ b/src/Config.php
@@ -166,12 +166,17 @@ class Config implements ConfigInterface
{
$options = array_merge(
[
- 'strategy' => $this->getOption('defaultLoadStrategy')
+ ... | Encapsulate reader and writer options. | ironedgesoftware_config | train |
bc0c3f6846337e3040ed761b34a164e176ee0784 | diff --git a/core/src/main/java/com/orientechnologies/orient/core/serialization/serializer/record/binary/ODocumentSerializerDeltaDistributed.java b/core/src/main/java/com/orientechnologies/orient/core/serialization/serializer/record/binary/ODocumentSerializerDeltaDistributed.java
index <HASH>..<HASH> 100644
--- a/core/... | add check for ridbag missing in delta deserialization | orientechnologies_orientdb | train |
205b35aee607f624b60dbc5c9c43f1ef50830853 | diff --git a/tests/Vps/Model/RowCache/Test.php b/tests/Vps/Model/RowCache/Test.php
index <HASH>..<HASH> 100644
--- a/tests/Vps/Model/RowCache/Test.php
+++ b/tests/Vps/Model/RowCache/Test.php
@@ -5,8 +5,7 @@
*/
class Vps_Model_RowCache_Test extends Vps_Test_TestCase
{
-
- protected function setUp()
+ publi... | Access level to Vps_Model_RowCache_Test::setUp() must be public (as in class Vps_Test_TestCase) | koala-framework_koala-framework | train |
ccad3db0071a48330ba01807bca7a34bbdf3911b | diff --git a/conn.go b/conn.go
index <HASH>..<HASH> 100644
--- a/conn.go
+++ b/conn.go
@@ -765,6 +765,12 @@ func (c *Conn) SetPongHandler(h func(string) error) {
c.handlePong = h
}
+// UnderlyingConn returns the internal net.Conn. This can be used to further
+// modifications to connection specific flags.
+func (c... | Added helper function UnderlyingConn to retrieve net.Conn from Conn objects. | gorilla_websocket | train |
41ef4331439d472eb981740f1d2ae155cdcf38ce | diff --git a/stl/mesh.py b/stl/mesh.py
index <HASH>..<HASH> 100644
--- a/stl/mesh.py
+++ b/stl/mesh.py
@@ -1,5 +1,4 @@
import numpy
-import itertools
import collections
from python_utils import logger
@@ -19,16 +18,30 @@ class Mesh(logger.Logged, collections.Mapping):
>>> data = numpy.zeros(10, dtype=Mesh.d... | removed obsolete methods and made everything more efficient | WoLpH_numpy-stl | train |
6ca2fc9c7aa875f96b8e4010cac57d12efe83114 | diff --git a/tests/test_ofx_formatter.py b/tests/test_ofx_formatter.py
index <HASH>..<HASH> 100644
--- a/tests/test_ofx_formatter.py
+++ b/tests/test_ofx_formatter.py
@@ -21,7 +21,7 @@ import re
import pytest
from ledgerautosync.converter import OfxConverter, SecurityList
-from ledgerautosync.ledgerwrap import HLed... | Fix test: LedgerPython does not support AutosyncPayee match | egh_ledger-autosync | train |
b618d8457334e5fd54165742b672a94abd3d7317 | diff --git a/test/acts_as_authentic_test/logged_in_status_test.rb b/test/acts_as_authentic_test/logged_in_status_test.rb
index <HASH>..<HASH> 100644
--- a/test/acts_as_authentic_test/logged_in_status_test.rb
+++ b/test/acts_as_authentic_test/logged_in_status_test.rb
@@ -19,7 +19,10 @@ module ActsAsAuthenticTest
... | Fix test that's broken in jruby because of timing issue
(<URL>) | binarylogic_authlogic | train |
edfde7434b9f08d47122c277489b6f1ff697f5e8 | diff --git a/nhlib/gsim/cauzzi_faccioli_2008.py b/nhlib/gsim/cauzzi_faccioli_2008.py
index <HASH>..<HASH> 100644
--- a/nhlib/gsim/cauzzi_faccioli_2008.py
+++ b/nhlib/gsim/cauzzi_faccioli_2008.py
@@ -177,14 +177,14 @@ class CauzziFaccioli2008(GMPE):
stddevs = []
for stddev_type in stddev_types:
... | renamed sigmaTM to sigma | gem_oq-engine | train |
608811f7dc27b21950cc1cbea8b045b052eaa0d0 | diff --git a/Classes/S3Target.php b/Classes/S3Target.php
index <HASH>..<HASH> 100644
--- a/Classes/S3Target.php
+++ b/Classes/S3Target.php
@@ -219,7 +219,9 @@ class S3Target implements TargetInterface
unset($potentiallyObsoleteObjects[$objectName]);
} else {
$o... | !!! disable public read and make configurable for cloudfront | flownative_flow-aws-s3 | train |
2e4654ac8c32561b8e5c8580046a96bbf42cc87b | diff --git a/tests/unit/Fixtures/call.php b/tests/unit/Fixtures/call.php
index <HASH>..<HASH> 100644
--- a/tests/unit/Fixtures/call.php
+++ b/tests/unit/Fixtures/call.php
@@ -57,7 +57,8 @@ switch ($test) {
case 'json':
$result = json_encode(array(
'code' => 0,
- ... | added unit test for postJson method, refs #<I> | twinh_wei | train |
0abfafa13b77bbf74681609bb75fa7ba725431c3 | diff --git a/core/client/tests/unit/models/user-test.js b/core/client/tests/unit/models/user-test.js
index <HASH>..<HASH> 100644
--- a/core/client/tests/unit/models/user-test.js
+++ b/core/client/tests/unit/models/user-test.js
@@ -74,13 +74,13 @@ describeModel(
var model = this.subject();
ru... | Fix `store.push` deprecations in user model test
no issue
- `store.push` now accepts a single argument that is a JSON API compliant object (<URL>) | TryGhost_Ghost | train |
b52684f860e41a0c65c65ec3756bf038a495f957 | diff --git a/conn.go b/conn.go
index <HASH>..<HASH> 100644
--- a/conn.go
+++ b/conn.go
@@ -2,6 +2,7 @@ package websocket
import (
"bytes"
+ "fmt"
"io"
"net/url"
"time"
@@ -10,16 +11,36 @@ import (
"honnef.co/go/js/dom"
)
-func beginHandlerOpen(ch chan error) func(ev js.Object) {
+func beginHandlerOpen(c... | In the process of testing, a few bugs were fixed. Dial also returns more informative errors. | gopherjs_websocket | train |
1daa4e23ec2dd40c6b490849276524264787e24e | diff --git a/semantic_release/history/logs.py b/semantic_release/history/logs.py
index <HASH>..<HASH> 100644
--- a/semantic_release/history/logs.py
+++ b/semantic_release/history/logs.py
@@ -48,6 +48,9 @@ def evaluate_version_bump(current_version: str, force: str = None) -> Optional[s
if commit_message.startsw... | fix: Only overwrite with patch if bump is None
Fixes #<I> | relekang_python-semantic-release | train |
c6277ff23d2c790c4cf2f0d262729d18d3e9129f | diff --git a/Changelog.md b/Changelog.md
index <HASH>..<HASH> 100644
--- a/Changelog.md
+++ b/Changelog.md
@@ -56,6 +56,7 @@
* Do not hangup on parsing Coordinates with `#`
* Fix crash on parsing Coordinates consist of `!`
* Fix crash on `Delimeter`
+* Fix crash on parsing `Coordinates` with sheet name with `!`
#... | Fix crash on parsing `Coordinates` with sheet name with `!` | ONLYOFFICE_ooxml_parser | train |
9319f4a0f0d8fffbc17d0407db5578725a61c112 | diff --git a/integration/gateway/gateway_test.go b/integration/gateway/gateway_test.go
index <HASH>..<HASH> 100644
--- a/integration/gateway/gateway_test.go
+++ b/integration/gateway/gateway_test.go
@@ -156,6 +156,9 @@ var _ = Describe("GatewayService", func() {
Expect(proto.Equal(result, expectedResult)).To(BeTrue... | Prepared tx must be signed before submission
The integration test isn't signing the prepared transaction before
submission and the transaction is being rejected by the orderer. This
change adds an explicit check for the signature in the gateway and fixes
the test to add the signature. | hyperledger_fabric | train |
8a5406a1b0b6969b80fb43990f4dbe6a5e2d8d91 | diff --git a/js/jquery.fileupload.js b/js/jquery.fileupload.js
index <HASH>..<HASH> 100644
--- a/js/jquery.fileupload.js
+++ b/js/jquery.fileupload.js
@@ -146,11 +146,14 @@
// If the singleFileUploads option is enabled, this callback will be
// called once for each file in the selection for XH... | groups sentences into paragraphs and adds subject to one sentence | blueimp_jQuery-File-Upload | train |
809439e20e273ce0d25c1d04e111dcf6011eb566 | diff --git a/src/ua-parser.js b/src/ua-parser.js
index <HASH>..<HASH> 100755
--- a/src/ua-parser.js
+++ b/src/ua-parser.js
@@ -620,7 +620,7 @@
/android.+[;\/]\s*(Q[T|M][\d\w]+)\s+build/i // Verizon Tablet
], [MODEL, [VENDOR, 'Verizon'], [TYPE, TABLET]], [
- ... | Fix potential ReDoS vulnerability as reported by Doyensec | faisalman_ua-parser-js | train |
de876f0f546a3181852bd3018be616fdf84cf85d | diff --git a/src/Database/Expression/Comparison.php b/src/Database/Expression/Comparison.php
index <HASH>..<HASH> 100644
--- a/src/Database/Expression/Comparison.php
+++ b/src/Database/Expression/Comparison.php
@@ -131,10 +131,17 @@ class Comparison extends QueryExpression {
$template = '%s %s (%s)';
$type = st... | Changing the empty conditions list approach as not all drivers were happy | cakephp_cakephp | train |
d8fe5e54e40ee32ee87ce58e812752b3c27b0498 | diff --git a/lib/data_mapper/mapper/relationship/builder/many_to_many.rb b/lib/data_mapper/mapper/relationship/builder/many_to_many.rb
index <HASH>..<HASH> 100644
--- a/lib/data_mapper/mapper/relationship/builder/many_to_many.rb
+++ b/lib/data_mapper/mapper/relationship/builder/many_to_many.rb
@@ -27,7 +27,9 @@ module ... | Only rename existing attributes in M:N join relation | rom-rb_rom | train |
ba035c44e76b2ecf8a8341d4ee7a4e1c5f3110d0 | diff --git a/src/schemas/map-style-schema.js b/src/schemas/map-style-schema.js
index <HASH>..<HASH> 100644
--- a/src/schemas/map-style-schema.js
+++ b/src/schemas/map-style-schema.js
@@ -52,7 +52,8 @@ class MapStyleSchemaV1 extends Schema {
}
load(mapStyles) {
- return {[this.key]: mapStyles}
+ // If mapS... | [bug] fix a bug where mapStyles is loaded as an empty object (#<I>) | keplergl_kepler.gl | train |
c48c0d62950d28e0c0cb01cfb25bef3b21cc0529 | diff --git a/cake/console/libs/tasks/view.php b/cake/console/libs/tasks/view.php
index <HASH>..<HASH> 100644
--- a/cake/console/libs/tasks/view.php
+++ b/cake/console/libs/tasks/view.php
@@ -366,6 +366,9 @@ class ViewTask extends BakeTask {
if ($content === true) {
$content = $this->getContent($action);
}
+ ... | Fixing issue where ViewTask would make empty view files for actions that did not have templates. Test case added. Fixes #<I> | cakephp_cakephp | train |
4e8c6075a6285a4716e302c80e7fb7fe83530418 | diff --git a/samtranslator/plugins/application/serverless_app_plugin.py b/samtranslator/plugins/application/serverless_app_plugin.py
index <HASH>..<HASH> 100644
--- a/samtranslator/plugins/application/serverless_app_plugin.py
+++ b/samtranslator/plugins/application/serverless_app_plugin.py
@@ -360,7 +360,6 @@ class Ser... | Remove logging of SAR service call response (#<I>) | awslabs_serverless-application-model | train |
5ba9d93afb9a362bd99a23e71d29f5684478e7f4 | diff --git a/libkbfs/folder_branch_ops.go b/libkbfs/folder_branch_ops.go
index <HASH>..<HASH> 100644
--- a/libkbfs/folder_branch_ops.go
+++ b/libkbfs/folder_branch_ops.go
@@ -4211,10 +4211,14 @@ func (fbo *folderBranchOps) Sync(ctx context.Context, file Node) (err error) {
if err != nil {
return
}
+ defer func()... | folder_branch_ops: don't use func lState during a defer in Sync
If the context is canceled, it's possible for the defer function to
race with the `doMDWriteWithRetry` function, and for the locks to look
interleaved, causing a panic.
Issue: KBFS-<I> | keybase_client | train |
20e41dd6bdc1579a33be62c4ba373cbd93cee898 | diff --git a/session.go b/session.go
index <HASH>..<HASH> 100644
--- a/session.go
+++ b/session.go
@@ -248,20 +248,18 @@ func (s *Session) recvLoop() {
}
s.streamLock.Unlock()
case cmdPSH:
- var written int64
- var err error
s.streamLock.Lock()
- if stream, ok := s.streams[sid]; ok {
- w... | make sure streamLock is non-blocking due to receiveBytes | xtaci_smux | train |
198c7900609715368b0531892778d16e4e63ad83 | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -56,6 +56,8 @@ setup(
'Programming Language :: Python :: 3.4',
'Programming Language :: Python :: 3.5',
'Programming Language :: Python :: 3.6',
+ 'Programming Language :: Python :: 3.7',
+ ... | Added more classifiers.
Since grpcio is used, PyPy isn't supported.
Also, we do support <I>. | pachyderm_python-pachyderm | train |
5e4471a9524c2a0ed0ad5d9e65ce7633e059b40f | diff --git a/src/Symfony/Component/Validator/Constraints/ExpressionLanguageSyntaxValidator.php b/src/Symfony/Component/Validator/Constraints/ExpressionLanguageSyntaxValidator.php
index <HASH>..<HASH> 100644
--- a/src/Symfony/Component/Validator/Constraints/ExpressionLanguageSyntaxValidator.php
+++ b/src/Symfony/Compone... | Throw error with debug message when ExpressionLanguage Component is not installed | symfony_symfony | train |
c416f74cf3b5f4c337ce5bdcb044b8c4c7665616 | diff --git a/django_socketio/channels.py b/django_socketio/channels.py
index <HASH>..<HASH> 100644
--- a/django_socketio/channels.py
+++ b/django_socketio/channels.py
@@ -59,13 +59,6 @@ class ChanneledSocketIOProtocol(object):
if subscriber != self.socket.session.session_id:
self._... | Implement a mock object allowing chained missing attributes to be accessed. | stephenmcd_django-socketio | train |
248745cb175570bae1735fc68c77a9449edf3e3b | diff --git a/pom.xml b/pom.xml
index <HASH>..<HASH> 100644
--- a/pom.xml
+++ b/pom.xml
@@ -24,7 +24,7 @@
<groupId>com.github.redfish4ktc.soapui</groupId>
<artifactId>maven-soapui-extension-plugin</artifactId>
- <version>4.5.1.5-SNAPSHOT</version>
+ <version>4.6.1.0-SNAPSHOT</version>
<packaging>jar</packag... | Start soapui <I> support (compile) #<I>
Add commons-lang3 dependency to make compilation pass (see comments in pom
for explanation) | redfish4ktc_maven-soapui-extension-plugin | train |
0494708b0a403d4a79936f567131f21000d62b91 | diff --git a/testing/redis.go b/testing/redis.go
index <HASH>..<HASH> 100644
--- a/spec/mongoid/tree/ordering_spec.rb
+++ b/spec/mongoid/tree/ordering_spec.rb
@@ -62,6 +62,13 @@ describe Mongoid::Tree::Ordering do
other_child.save!
node(:another_child).position.should =... | Added failing spec for repositioning of siblings of unsaved nodes. | benedikt_mongoid-tree | train |
b9a7011e6e24daa3c9c41129382557889abf6127 | diff --git a/src/DI/DbalConsoleExtension.php b/src/DI/DbalConsoleExtension.php
index <HASH>..<HASH> 100644
--- a/src/DI/DbalConsoleExtension.php
+++ b/src/DI/DbalConsoleExtension.php
@@ -61,7 +61,7 @@ class DbalConsoleExtension extends CompilerExtension
// Register helpers
$connectionHelper = $this->prefix('@co... | DbalConsoleExtension: fixed ConnectionHelper alias needed by ImportCommand | nettrine_dbal | train |
d32d91e12ff250aaef8d68c04fe0daefb34dd451 | diff --git a/bqplot/axes.py b/bqplot/axes.py
index <HASH>..<HASH> 100644
--- a/bqplot/axes.py
+++ b/bqplot/axes.py
@@ -78,7 +78,7 @@ class Axis(BaseAxis):
label: string (default: '')
The axis label
tick_format: string or None (default: '')
- The tick format for the axis.
+ The tick form... | clarify what date format is used for date based tick_formats | bloomberg_bqplot | train |
63b7ae888f2533ca9a17c8c9435b4bed99afcfd5 | diff --git a/js/jquery.tooltipster.js b/js/jquery.tooltipster.js
index <HASH>..<HASH> 100644
--- a/js/jquery.tooltipster.js
+++ b/js/jquery.tooltipster.js
@@ -892,14 +892,24 @@ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLI
// self represent the instance of the tooltipster plugin... | Merged the 'content' and 'update' methods. 'update' is still working for retrocompatibility but is deprecated. | iamceege_tooltipster | train |
10b1dba5513ffe0696186313c9636419e776f472 | diff --git a/spec/buildbox/buildbox/command_spec.rb b/spec/buildbox/buildbox/command_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/buildbox/buildbox/command_spec.rb
+++ b/spec/buildbox/buildbox/command_spec.rb
@@ -5,7 +5,7 @@ require "spec_helper"
describe Buildbox::Command do
describe "#run" do
it "is run wi... | Fixed the tty spec. | buildkite_buildbox-agent-ruby | train |
3b81f2c293ed868d586d18c8bac69c21d36c8e18 | diff --git a/server/heroku/logs.go b/server/heroku/logs.go
index <HASH>..<HASH> 100644
--- a/server/heroku/logs.go
+++ b/server/heroku/logs.go
@@ -1,6 +1,7 @@
package heroku
import (
+ "fmt"
"net/http"
"time"
@@ -20,13 +21,14 @@ type PostLogsForm struct {
func (h *PostLogs) ServeHTTPContext(ctx context.Conte... | Backwards compatability with the old emp cli
If we get an empty body (from the old emp cli) just use the default form
values. | remind101_empire | train |
80cd3fc63596d85b4e96826652c488cb0f115dd7 | diff --git a/dev/com.ibm.ws.concurrent_fat_ejb/fat/src/com/ibm/ws/concurrent/ejb/fat/ConcurrentEJBTest.java b/dev/com.ibm.ws.concurrent_fat_ejb/fat/src/com/ibm/ws/concurrent/ejb/fat/ConcurrentEJBTest.java
index <HASH>..<HASH> 100644
--- a/dev/com.ibm.ws.concurrent_fat_ejb/fat/src/com/ibm/ws/concurrent/ejb/fat/Concurren... | Issue #<I> code review comment to remove unnecessary code | OpenLiberty_open-liberty | train |
c6666ed6008c3052668344f745417379b8703bd9 | diff --git a/test/index.js b/test/index.js
index <HASH>..<HASH> 100644
--- a/test/index.js
+++ b/test/index.js
@@ -110,21 +110,4 @@ describe('The public interface', function() {
assert(pub.path);
assert.equal(pub.path, pub.toString());
});
-
- it('should print a warning when passing a function to require(), but... | test: Removed test for dropped feature | inxilpro_node-app-root-path | train |
26db8be0ee95d0cc13f1a7f4e6c2f519f5abefb6 | diff --git a/ssbio/test/conftest.py b/ssbio/test/conftest.py
index <HASH>..<HASH> 100644
--- a/ssbio/test/conftest.py
+++ b/ssbio/test/conftest.py
@@ -43,6 +43,20 @@ def test_files_outputs(test_files):
@pytest.fixture(scope='module')
+def test_files_atlas(test_files):
+ """ATLAS files"""
+ # ssbio/test/test_... | Many more GEMPRO pipeline tests!
(cherry picked from commit <I>ad) | SBRG_ssbio | train |
ba39cc1709e12d1e5ecff21cce3615a30e733993 | diff --git a/client/hotrod-client/src/main/java/org/infinispan/client/hotrod/impl/transport/tcp/SaslTransportObjectFactory.java b/client/hotrod-client/src/main/java/org/infinispan/client/hotrod/impl/transport/tcp/SaslTransportObjectFactory.java
index <HASH>..<HASH> 100644
--- a/client/hotrod-client/src/main/java/org/in... | ISPN-<I> Wrap evaluateChallenge in PrivilegedAction when a client
subject has been specified (GSSAPI) | infinispan_infinispan | train |
c008e48b23911145ccf4b2681386861f643c7d8c | diff --git a/server/zclient.go b/server/zclient.go
index <HASH>..<HASH> 100644
--- a/server/zclient.go
+++ b/server/zclient.go
@@ -186,8 +186,5 @@ func NewZclient(url string, redistRouteTypes []config.InstallProtocolType) (*zeb
}
cli.SendRedistribute(t)
}
- if e := cli.SendCommand(zebra.REDISTRIBUTE_DEFAULT_ADD... | server: fix wrong usage of zapi
sending REDISTRIBUTE_DEFAULT_ADD command causes getting every routes
zebra has which is not desirable behavior | osrg_gobgp | train |
3fec99cb15fd507ad94538c39b1bcfae31e4cf93 | diff --git a/openxc/measurements.py b/openxc/measurements.py
index <HASH>..<HASH> 100644
--- a/openxc/measurements.py
+++ b/openxc/measurements.py
@@ -35,11 +35,14 @@ class Measurement(AgingData):
"""
super(Measurement, self).__init__()
self.name = name
- if override_unit:
+ if ... | Allow non-unitized boolean measurements. | openxc_openxc-python | train |
5e8e7e898764ea4e3f39aaac73cb3906216ef842 | diff --git a/jtime/configuration.py b/jtime/configuration.py
index <HASH>..<HASH> 100644
--- a/jtime/configuration.py
+++ b/jtime/configuration.py
@@ -29,6 +29,10 @@ def load_config():
return d
+def _delete_config():
+ os.path.exists(_config) and os.remove(_config)
+
+
def _save_config(jira_url, username, ... | Adding some logic to handle config problems, specifically HTTP <I>s. | mapmyfitness_jtime | train |
d2ed2acb9c2dadcb301abcd5a2046a6ba34210d6 | diff --git a/README.md b/README.md
index <HASH>..<HASH> 100644
--- a/README.md
+++ b/README.md
@@ -108,7 +108,7 @@ Alternatively, you can import our *bill of materials*...
</dependency>
<dependency>
<groupId>org.zalando</groupId>
- <artifactId>logbook-logstash-logback-encoder</artifactId>
+ <artifactId... | More QA adjustments for Logstash module | zalando_logbook | train |
0e5fc051a977ae76789779867e485ec9bbd9495f | diff --git a/src/Core/Framework/DataAbstractionLayer/Dbal/EntityReader.php b/src/Core/Framework/DataAbstractionLayer/Dbal/EntityReader.php
index <HASH>..<HASH> 100644
--- a/src/Core/Framework/DataAbstractionLayer/Dbal/EntityReader.php
+++ b/src/Core/Framework/DataAbstractionLayer/Dbal/EntityReader.php
@@ -293,22 +293,1... | Fix loading of nested ManyToMany entities in entity reader | shopware_platform | train |
926b2f5fd153d5f325df7fe00b13f619edcb6bc5 | diff --git a/src/DynamicRedirect.js b/src/DynamicRedirect.js
index <HASH>..<HASH> 100644
--- a/src/DynamicRedirect.js
+++ b/src/DynamicRedirect.js
@@ -64,34 +64,38 @@ class DynamicRedirect {
return this;
}
- async match(path) {
- if (!this._data) {
- try {
- let url = new URL(this._src);
- ... | refactor(redirect): extract fetch method | adobe_helix-shared | train |
72db18a4328875b5eb97ce33381c2f92392cd579 | diff --git a/cf/commands/service/update_service.go b/cf/commands/service/update_service.go
index <HASH>..<HASH> 100644
--- a/cf/commands/service/update_service.go
+++ b/cf/commands/service/update_service.go
@@ -9,6 +9,7 @@ import (
"github.com/cloudfoundry/cli/cf/configuration/core_config"
"github.com/cloudfoundry/... | update-service shows an error if the instance is missing and no plan is provided | cloudfoundry_cli | train |
c972d24f75e6f47bf8d8efcd97da1f913a1541ba | diff --git a/spec/remove.spec.js b/spec/remove.spec.js
index <HASH>..<HASH> 100644
--- a/spec/remove.spec.js
+++ b/spec/remove.spec.js
@@ -101,4 +101,40 @@ describe('remove', function () {
});
});
+ describe('*nix specific', function () {
+
+ if (process.platform === 'win32') {
+ ... | Make sure remove() doesn't follow symlinks | szwacz_fs-jetpack | train |
acfc09415e4b34c0dafc1d04bf60dd6beadae9dc | diff --git a/src/error.js b/src/error.js
index <HASH>..<HASH> 100644
--- a/src/error.js
+++ b/src/error.js
@@ -1,3 +1,8 @@
-export class MobilityError extends Error {}
-export class CheckError extends Error {}
-export class PromotionError extends Error {}
+export class ChessError {
+ constructor() {
+ this.name = t... | test: last tests before I fall asleep | chessfish_chesslib | train |
13d375aa2537a99afc4628ebc43122bca2fb6d46 | diff --git a/code/libraries/koowa/template/abstract.php b/code/libraries/koowa/template/abstract.php
index <HASH>..<HASH> 100644
--- a/code/libraries/koowa/template/abstract.php
+++ b/code/libraries/koowa/template/abstract.php
@@ -120,7 +120,7 @@ abstract class KTemplateAbstract extends KObject implements KObjectIdenti... | Allow for filter object cascading. | timble_kodekit | train |
978e5b6fbe6a896b8492a4c31a1ff7609d877678 | diff --git a/lib/chef/knife/block.rb b/lib/chef/knife/block.rb
index <HASH>..<HASH> 100644
--- a/lib/chef/knife/block.rb
+++ b/lib/chef/knife/block.rb
@@ -15,7 +15,7 @@ class Chef
# locate_config_file is only compatible with Chef 11
_chef11 = ::Chef::Version.new('11.0.0')
if GreenAndSecure.current_... | Update locate_config_file scope to reflect its change to a Class method
The locate_config_file was changed to a class method on <I>-<I>-<I>:
<URL> | knife-block_knife-block | train |
173da428e3f185b16acbe29ccd72ad6720194fa8 | diff --git a/app/helpers/bento_search_helper.rb b/app/helpers/bento_search_helper.rb
index <HASH>..<HASH> 100644
--- a/app/helpers/bento_search_helper.rb
+++ b/app/helpers/bento_search_helper.rb
@@ -145,7 +145,7 @@ module BentoSearchHelper
def bento_sort_hash_for(engine)
Hash[
engine.sort_definitions.ke... | confstruct keys now turn to symbols even if they started out strings | jrochkind_bento_search | train |
f182a4996c6e2962a00b84c32b3a36e1dd5849bc | diff --git a/bokeh/core/_templates/autoload_nb_js.js b/bokeh/core/_templates/autoload_nb_js.js
index <HASH>..<HASH> 100644
--- a/bokeh/core/_templates/autoload_nb_js.js
+++ b/bokeh/core/_templates/autoload_nb_js.js
@@ -32,8 +32,8 @@
if (server_id !== undefined) {
// Clean up Bokeh references
- const ... | Fix regressions after PR #<I> (#<I>) | bokeh_bokeh | train |
8efa3852917625719156ff638dd57f0a6e88f783 | diff --git a/tests/unit/utils/utils_test.py b/tests/unit/utils/utils_test.py
index <HASH>..<HASH> 100644
--- a/tests/unit/utils/utils_test.py
+++ b/tests/unit/utils/utils_test.py
@@ -307,7 +307,6 @@ class UtilsTestCase(TestCase):
expected_ret = {'foo': {'new': 'woz', 'old': 'bar'}}
self.assertDictEqua... | More unit tests. Many, many more. | saltstack_salt | train |
f9ce3b782b9ed38e7a5faadc4e7c252118865250 | diff --git a/tests/dummy/app/components/x-music/component.js b/tests/dummy/app/components/x-music/component.js
index <HASH>..<HASH> 100644
--- a/tests/dummy/app/components/x-music/component.js
+++ b/tests/dummy/app/components/x-music/component.js
@@ -50,7 +50,13 @@ export default Ember.Component.extend({
yield... | teardown audio context in x-music example | machty_ember-concurrency | train |
a7c4097fb85f823dd8e1810538525df6e5296122 | diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -4,6 +4,7 @@ var Queue = require('fastqueue');
module.exports = function (input, delimiter, consumer, cb) {
var queue = new Queue;
var closed = false;
+ var sealed = false;
var processing = false;
var chunk = '';... | Ensure cb doesn't get called multiple times | diamondio_input-stream-parser | train |
41680d4b08141760634bd2468959532acfbd1856 | diff --git a/wcomponents-core/src/test/java/com/github/bordertech/wcomponents/render/webxml/WTabRenderer_Test.java b/wcomponents-core/src/test/java/com/github/bordertech/wcomponents/render/webxml/WTabRenderer_Test.java
index <HASH>..<HASH> 100755
--- a/wcomponents-core/src/test/java/com/github/bordertech/wcomponents/re... | Add unit test for WTabRenderer
Adds test for toolTip | BorderTech_wcomponents | train |
6f6ca1f49d879209456d6fae643da9d846634348 | diff --git a/example/test-custom-assert-methods.js b/example/test-custom-assert-methods.js
index <HASH>..<HASH> 100644
--- a/example/test-custom-assert-methods.js
+++ b/example/test-custom-assert-methods.js
@@ -47,3 +47,19 @@ exports['test_assert.response'] = function(test, assert) {
test.finish();
});
};
+
+e... | Add tests for other custom assert functions. | cloudkick_whiskey | train |
6036bc1ecac8c1ca13c8276b276f13212a257601 | diff --git a/engine/src/main/java/org/camunda/bpm/engine/impl/cfg/ProcessEngineConfigurationImpl.java b/engine/src/main/java/org/camunda/bpm/engine/impl/cfg/ProcessEngineConfigurationImpl.java
index <HASH>..<HASH> 100644
--- a/engine/src/main/java/org/camunda/bpm/engine/impl/cfg/ProcessEngineConfigurationImpl.java
+++ ... | chore(engine): rename legacy user operation log configuration property
- new name is restrictUserOperationLogToAuthenticatedUsers which is more
specific and avoids problems if we add another such configuration flag
in the future
related to CAM-<I> | camunda_camunda-bpm-platform | train |
853fa96409cb9a19af01022f7eda2160e0a181cd | diff --git a/lib/fog/compute.rb b/lib/fog/compute.rb
index <HASH>..<HASH> 100644
--- a/lib/fog/compute.rb
+++ b/lib/fog/compute.rb
@@ -51,7 +51,7 @@ module Fog
Fog::Compute::Linode.new(attributes)
when :new_servers
require 'fog/bare_metal_cloud/compute'
- warn "[DEPRECATION] `new_servers... | [core] Uses Logger deprecation for Compute.new
Two Compute providers were issuing deprecation warnings to Kernel#warn
which bypassed highlighting and any future suppressing | fog_fog | train |
69afcc40603d15fa1882b0df5e8ae3d1a182d04b | diff --git a/salt/states/slack.py b/salt/states/slack.py
index <HASH>..<HASH> 100644
--- a/salt/states/slack.py
+++ b/salt/states/slack.py
@@ -24,6 +24,7 @@ The api key can be specified in the master or minion configuration like below:
api_key: peWcBiMOS9HrZG15peWcBiMOS9HrZG15
'''
+from salt.exceptions import... | Handle exception when no Slack API key was provided | saltstack_salt | train |
9c50d8489a068a0c6949b06b2a2929648d5a4f0a | diff --git a/template.php b/template.php
index <HASH>..<HASH> 100644
--- a/template.php
+++ b/template.php
@@ -316,10 +316,10 @@ class Template extends View {
$tree=array(),$node=&$tree,
$stack=array(),$depth=0,$tmp='';$ptr<$len;)
if (preg_match('/^<(\/?)(?:F3:)?'.
- '('.$this->tags.')\b'.
- ... | Tweak custom tag support; Add unit tests (Feature request #<I>) | bcosca_fatfree-core | train |
2a3493e98afe8bb9519bb33a0190df32a76a9814 | diff --git a/Classes/Sitegeist/MagicWand/DBAL/SimpleDBAL.php b/Classes/Sitegeist/MagicWand/DBAL/SimpleDBAL.php
index <HASH>..<HASH> 100644
--- a/Classes/Sitegeist/MagicWand/DBAL/SimpleDBAL.php
+++ b/Classes/Sitegeist/MagicWand/DBAL/SimpleDBAL.php
@@ -19,7 +19,7 @@ class SimpleDBAL {
* @param string $database
... | BUGFIX: Support null as host-value | sitegeist_Sitegeist.MagicWand | train |
7c484ab7447ec4d9ba65ffd17d0c8bb48f97145d | diff --git a/perceval/backend.py b/perceval/backend.py
index <HASH>..<HASH> 100644
--- a/perceval/backend.py
+++ b/perceval/backend.py
@@ -32,7 +32,9 @@ from datetime import datetime as dt
from ._version import __version__
from .cache import Cache, setup_cache
-from .utils import DEFAULT_DATETIME, str_to_datetime
+... | [backend] Generalize BackendCommand to run any type of backend
The usage of introspection on __init__ and run() methods, allows
to have a generic command class that can run any type of backend.
Thus, minimal BackendCommand subclasses implementation will be
needed to support the distinct kind of backends Perceval can
e... | chaoss_grimoirelab-perceval | train |
814567ae5749fd05727fcb9e7afc2fe65e162e7f | diff --git a/python/segyio/segy.py b/python/segyio/segy.py
index <HASH>..<HASH> 100644
--- a/python/segyio/segy.py
+++ b/python/segyio/segy.py
@@ -1,18 +1,3 @@
-"""segyio modes
-
-Welcome to segyio modes. Here you will find references and examples for the
-various segy modes and how to interact with segy files. To star... | Remove segyio.segy module doc, move to SegyFile
This was largely a help text on how to use pydoc, but documentation is
largely now meant to be consumed on readthedocs, so this intro is
unnecessary. | equinor_segyio | train |
6feabbcd28adde4dd29754bcee2e72f45d3c9036 | diff --git a/flink-core/src/main/java/org/apache/flink/util/function/BiFunctionWithException.java b/flink-core/src/main/java/org/apache/flink/util/function/BiFunctionWithException.java
index <HASH>..<HASH> 100644
--- a/flink-core/src/main/java/org/apache/flink/util/function/BiFunctionWithException.java
+++ b/flink-core... | [hotfix] Add BiFunctionWithException#unchecked to convert into BiFunction | apache_flink | train |
43ef70dd14c3f37020271bb9fedb74158fe8a275 | diff --git a/library/Garp/Spawn/MySql/Manager.php b/library/Garp/Spawn/MySql/Manager.php
index <HASH>..<HASH> 100755
--- a/library/Garp/Spawn/MySql/Manager.php
+++ b/library/Garp/Spawn/MySql/Manager.php
@@ -11,7 +11,9 @@ class Garp_Spawn_MySql_Manager {
const CUSTOM_SQL_PATH =
'/data/sql/spawn.sql';
... | Prevent 'g spawn' from asking for empty database passwords.
Use case: development installs without a passwords, e.g. Homebrew Mysql | grrr-amsterdam_garp3 | train |
e5ef491072178e005efc5b4abc44db48016f2dba | diff --git a/lib/locomotive/steam/liquid/tags/inherited_block.rb b/lib/locomotive/steam/liquid/tags/inherited_block.rb
index <HASH>..<HASH> 100644
--- a/lib/locomotive/steam/liquid/tags/inherited_block.rb
+++ b/lib/locomotive/steam/liquid/tags/inherited_block.rb
@@ -18,7 +18,7 @@ module Locomotive
def initia... | when live_editing mode is on, insert an anchor before a block (opt-in), it'll be used by the back-office for a better user experience | locomotivecms_steam | train |
fccdd2ea21ee4bcfcb1a27a9da7a1517e8bfb101 | diff --git a/rekt/__init__.py b/rekt/__init__.py
index <HASH>..<HASH> 100644
--- a/rekt/__init__.py
+++ b/rekt/__init__.py
@@ -9,10 +9,7 @@ many service specific rest wrappers especially for google apis, this
library is meant to be generic and dynamic enough by templating the common
client code for most rest services... | Bumping version changing from named tuple to dynamic response object for the request class | dillonhicks_rekt | train |
61fc36b36e40eab9d0aaeafb6325851bbdcd65e0 | diff --git a/bin/eustia.js b/bin/eustia.js
index <HASH>..<HASH> 100755
--- a/bin/eustia.js
+++ b/bin/eustia.js
@@ -8,20 +8,20 @@ var nopt = require('nopt'),
_ = require('../lib/util');
var knowOpts = {
- encoding : String,
+ encoding: String,
extension: Array,
- output : String,
... | Dev: Entry code refactoring | liriliri_eustia | train |
195e6fd2bd185ee6c4aa62b0a1e3faaa6f42d094 | diff --git a/aws/resource_aws_cognito_user_pool_client.go b/aws/resource_aws_cognito_user_pool_client.go
index <HASH>..<HASH> 100644
--- a/aws/resource_aws_cognito_user_pool_client.go
+++ b/aws/resource_aws_cognito_user_pool_client.go
@@ -3,6 +3,7 @@ package aws
import (
"fmt"
"log"
+ "regexp"
"strings"
"git... | use enum slices + use built in validation func | terraform-providers_terraform-provider-aws | train |
33ca18edecb88f32a20697e2eb2e14968365192d | diff --git a/progressive/__init__.py b/progressive/__init__.py
index <HASH>..<HASH> 100644
--- a/progressive/__init__.py
+++ b/progressive/__init__.py
@@ -1 +1 @@
-__version__ = "0.3.0"
+__version__ = "0.3.1" | Do a <I> bugfix release | hfaran_progressive | train |
0485d6998378bdd3355396ad8326faad7a7a08c3 | diff --git a/app/services/redux.js b/app/services/redux.js
index <HASH>..<HASH> 100644
--- a/app/services/redux.js
+++ b/app/services/redux.js
@@ -28,7 +28,7 @@ var createStoreWithMiddleware = compose(applyMiddleware(...middleware), enhancer
export default Ember.Service.extend({
init() {
this.store = cre... | pass store into function when building redux service | ember-redux_ember-redux | train |
669708b13f831da97bc44b088985f2c0a7d34f0f | diff --git a/python/nanotime/__init__.py b/python/nanotime/__init__.py
index <HASH>..<HASH> 100644
--- a/python/nanotime/__init__.py
+++ b/python/nanotime/__init__.py
@@ -87,7 +87,7 @@ class nanotime(object):
if isinstance(other, self.__class__):
return cmp(self._ns, other._ns)
else:
- return cmp(... | Fixed a bug where _converter was referenced as converter | jbenet_nanotime | train |
0fed8a0b344c571e3e4f4a0da7da8f1de5ead809 | diff --git a/dipper/sources/EOM.py b/dipper/sources/EOM.py
index <HASH>..<HASH> 100644
--- a/dipper/sources/EOM.py
+++ b/dipper/sources/EOM.py
@@ -121,7 +121,7 @@ class EOM(PostgreSQLSource):
IAO:definition Literal(objective_def. subjective def)
foaf:depiction Literal(small_image_url),... | change dc:comment to rdfs:comment in a doc string | monarch-initiative_dipper | train |
df391bbfbc82b76637e746af82131e9aee07356a | diff --git a/lib/wavefile/format.rb b/lib/wavefile/format.rb
index <HASH>..<HASH> 100644
--- a/lib/wavefile/format.rb
+++ b/lib/wavefile/format.rb
@@ -4,11 +4,13 @@ module WaveFile
class Format
MAX_CHANNELS = 65535
SUPPORTED_BITS_PER_SAMPLE = [8, 16, 32]
+ MAX_SAMPLE_RATE = 4_294_967_296
def init... | Adding validation for Format.sample_rate | jstrait_wavefile | train |
9d549a0c06feb0de9f31cd574e7864c308573698 | diff --git a/testing/test_dsession.py b/testing/test_dsession.py
index <HASH>..<HASH> 100644
--- a/testing/test_dsession.py
+++ b/testing/test_dsession.py
@@ -146,6 +146,25 @@ class TestLoadScheduling:
crashitem = sched.remove_node(node)
assert crashitem == collection[0]
+ def test_schedule_diffe... | Log different tests collected by slaves instead of an error
This is a proposal to fix #<I>. | pytest-dev_pytest-xdist | train |
aed9d768443c5fab1387d29a1ce96c048634fb5b | diff --git a/salmonella/static/salmonella.js b/salmonella/static/salmonella.js
index <HASH>..<HASH> 100644
--- a/salmonella/static/salmonella.js
+++ b/salmonella/static/salmonella.js
@@ -16,6 +16,8 @@ function popup_wrapper(triggerLink, app_name, model_name){
return false;
}
+
+
(function($) {
$(document)... | Add an icon to clear the salmonella field | lincolnloop_django-dynamic-raw-id | train |
62d63cce063c8cd24ddfa39c4e13b5de5e40559c | diff --git a/traces/timeseries.py b/traces/timeseries.py
index <HASH>..<HASH> 100644
--- a/traces/timeseries.py
+++ b/traces/timeseries.py
@@ -38,6 +38,7 @@ def span_range(start, end, unit):
class TimeSeries(object):
+
"""A class to help manipulate and analyze time series that are the
result of taking me... | operation now takes a scalar as well as a timeseries | datascopeanalytics_traces | train |
ee7796ca99df1cde261cbbad34670e58564ac576 | diff --git a/src/runner/resolve-field.js b/src/runner/resolve-field.js
index <HASH>..<HASH> 100644
--- a/src/runner/resolve-field.js
+++ b/src/runner/resolve-field.js
@@ -30,21 +30,46 @@ export function stopMonitoringPerformance() {
return {timings: oldTimings, count: oldCount};
}
+const waitingFields = new Map()... | Resolve fields in parallel when running with performance monitoring enabled | bicyclejs_bicycle | train |
9a9c99190f9c3069f89d35571c87c30ef9f7cb22 | diff --git a/src/Illuminate/Foundation/Console/RouteListCommand.php b/src/Illuminate/Foundation/Console/RouteListCommand.php
index <HASH>..<HASH> 100644
--- a/src/Illuminate/Foundation/Console/RouteListCommand.php
+++ b/src/Illuminate/Foundation/Console/RouteListCommand.php
@@ -361,6 +361,8 @@ class RouteListCommand ex... | [9.x] Add counts to route:list command (#<I>)
* Added route counts to the route:list command.
* Only display count at the bottom of the CLI output. | laravel_framework | train |
a88d7d03c54041a5add83bd72c607f0f696bd324 | diff --git a/src/UtmCookie/UtmCookie.php b/src/UtmCookie/UtmCookie.php
index <HASH>..<HASH> 100644
--- a/src/UtmCookie/UtmCookie.php
+++ b/src/UtmCookie/UtmCookie.php
@@ -68,7 +68,7 @@ class UtmCookie
*
* @return void
*/
- private static function init()
+ public static function init()
{
// if initializat... | *edit - method init is public now - can be called only to initialize (early have to call get...) | xsuchy09_utm-cookie | train |
0bf63a7c993e57a6e0ade1f40f8f8cacd6e4e3dc | diff --git a/Kirin/core/common/javascript/src/services/Networking.js b/Kirin/core/common/javascript/src/services/Networking.js
index <HASH>..<HASH> 100644
--- a/Kirin/core/common/javascript/src/services/Networking.js
+++ b/Kirin/core/common/javascript/src/services/Networking.js
@@ -318,7 +318,9 @@ defineServiceModule("... | Call network is available on first call of registerBackgroundListener
This probably isn't the right time to do it (as the other calls to register may also be interested). | KirinJS_Kirin | train |
8b0567b26da7b4ddf9263ec7a2fdee57b93bd5d3 | diff --git a/tests/TestCase/Utility/TextTest.php b/tests/TestCase/Utility/TextTest.php
index <HASH>..<HASH> 100644
--- a/tests/TestCase/Utility/TextTest.php
+++ b/tests/TestCase/Utility/TextTest.php
@@ -423,14 +423,12 @@ TEXT;
$this->assertTextEquals($expected, $result, 'Text not wrapped.');
$result... | Fix issue with trim line ending and test content. | cakephp_cakephp | train |
ea4b1966e77d1cfaaadfe9627f02bc3f38015a6b | diff --git a/lib/rocket_job/jobs/re_encrypt/relational_job.rb b/lib/rocket_job/jobs/re_encrypt/relational_job.rb
index <HASH>..<HASH> 100644
--- a/lib/rocket_job/jobs/re_encrypt/relational_job.rb
+++ b/lib/rocket_job/jobs/re_encrypt/relational_job.rb
@@ -1,8 +1,5 @@
-begin
- require "active_record"
-rescue LoadError
-... | Relational Job only applies to ActiveRecord | rocketjob_rocketjob | train |
3b8a417cc4a7e187075c8daefefce80bee687caa | diff --git a/src/main/java/org/jdbdt/Query.java b/src/main/java/org/jdbdt/Query.java
index <HASH>..<HASH> 100644
--- a/src/main/java/org/jdbdt/Query.java
+++ b/src/main/java/org/jdbdt/Query.java
@@ -101,6 +101,12 @@ public final class Query extends DataSource {
private String orderByClause = null;
/**
+ * DIS... | Query: support for DISTINCT clause | JDBDT_jdbdt | train |
9c4a116792ab96939865fb506b010b7f403034d1 | diff --git a/test/async.js b/test/async.js
index <HASH>..<HASH> 100644
--- a/test/async.js
+++ b/test/async.js
@@ -81,6 +81,36 @@ module.exports = function(serializer) {
})
+ tape('sync', function (t) {
+ var client = {
+ syncOk : 'sync',
+ syncErr: 'sync'
+ }
+
+ var A = mux(client, null, se... | support sync methods (exposed as async, but handle errors etc, I found myself using this quite often in scuttlebot | ssbc_muxrpc | train |
b7b67f7922ca8e3be768d8e7125d8a9fb531d504 | diff --git a/test/credentials-test-as-root.js b/test/credentials-test-as-root.js
index <HASH>..<HASH> 100644
--- a/test/credentials-test-as-root.js
+++ b/test/credentials-test-as-root.js
@@ -41,11 +41,9 @@ var tinyApp = function(port, hostname, callback) {
var app = express.createServer();
- app.configure(f... | Remove deprecated app.configure() calls from tests | pump-io_pump.io | train |
b160020fa8f5b7d34bbff270e59ac51fb248450d | diff --git a/content/sql/user.go b/content/sql/user.go
index <HASH>..<HASH> 100644
--- a/content/sql/user.go
+++ b/content/sql/user.go
@@ -374,20 +374,19 @@ func (u *User) ArticlesById(ids []data.ArticleId, o ...data.ArticleQueryOptions)
login := u.Data().Login
u.logger.Infof("Getting articles %q for user %s\n", id... | Where IN is a bit faster than a list of ORs | urandom_readeef | train |
8da703fb4339085fd742309e90c9afc232b060b1 | diff --git a/gandi/cli/modules/cert.py b/gandi/cli/modules/cert.py
index <HASH>..<HASH> 100644
--- a/gandi/cli/modules/cert.py
+++ b/gandi/cli/modules/cert.py
@@ -47,7 +47,12 @@ class Certificate(GandiModule):
def package_list(cls, options=None):
""" list possible certificate packages """
options... | Handle Ote case where no cert api is exported. | Gandi_gandi.cli | train |
52a6baee91753209a462090adcd4213b2f51f333 | diff --git a/src/mako/utility/Collection.php b/src/mako/utility/Collection.php
index <HASH>..<HASH> 100644
--- a/src/mako/utility/Collection.php
+++ b/src/mako/utility/Collection.php
@@ -55,6 +55,64 @@ class Collection implements ArrayAccess, Countable, IteratorAggregate
}
/**
+ * Adds a new item to the collecti... | Added put, has, get, remove and clear methods to collection | mako-framework_framework | train |
dd9baceaa5d44ec43316a1a8d550e0bc44653893 | diff --git a/package.json b/package.json
index <HASH>..<HASH> 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
{
"name": "socket.io-rpc",
- "version": "0.0.11",
+ "version": "0.0.12",
"private": false,
"author": "capaj <capajj@gmail.com>",
"description": "Minimalistic remote proce... | * server channels should be deleted after disconnection and repeated load channel should return just the one promise, they should not try and connect again | capaj_socket.io-rpc | train |
bf86d9196819264110f6b469e0c7a4886b0477fd | diff --git a/public/lib/main.js b/public/lib/main.js
index <HASH>..<HASH> 100644
--- a/public/lib/main.js
+++ b/public/lib/main.js
@@ -21,17 +21,22 @@
});
socket.on('event:new_notification', function(data) {
- if (!data || !data.text) {
+ if (!data) {
return;
}
-
- translator.translate(data.tex... | data.text is deprecated | psychobunny_nodebb-plugin-desktop-notifications | train |
4898e22b106bf38471a2b066b5a0e2c1293aa735 | diff --git a/controller/QtiCreator.php b/controller/QtiCreator.php
index <HASH>..<HASH> 100755
--- a/controller/QtiCreator.php
+++ b/controller/QtiCreator.php
@@ -23,6 +23,7 @@ namespace oat\taoQtiItem\controller;
use common_exception_Error;
use core_kernel_classes_Resource;
+use oat\generis\model\data\event\Resour... | Trigger resourceUpdated event for upfate updatedAt | oat-sa_extension-tao-itemqti | train |
328c89cccada8b32bd791a121c754a434e6c42b8 | diff --git a/src/pyrocore/scripts/base.py b/src/pyrocore/scripts/base.py
index <HASH>..<HASH> 100644
--- a/src/pyrocore/scripts/base.py
+++ b/src/pyrocore/scripts/base.py
@@ -371,10 +371,10 @@ class ScriptBaseWithConfig(ScriptBase): # pylint: disable=abstract-method
setattr(config, key, load_config.va... | rtxmlrpc: restrict @connection to first argument (closes #<I>) | pyroscope_pyrocore | train |
512d03532e1b644a77249f9ecd25bcec75fac098 | diff --git a/src/Engines/TNTSearchEngine.php b/src/Engines/TNTSearchEngine.php
index <HASH>..<HASH> 100644
--- a/src/Engines/TNTSearchEngine.php
+++ b/src/Engines/TNTSearchEngine.php
@@ -331,6 +331,8 @@ class TNTSearchEngine extends Engine
private function handleSoftDeletes($builder, $model)
{
// rem... | adds comment to clarify default behaviour when scout.soft_delete configuration is disabled. | teamtnt_laravel-scout-tntsearch-driver | train |
6236d748a6f5b493b00965d752907583108d5eb0 | diff --git a/lib/active_scaffold/attribute_params.rb b/lib/active_scaffold/attribute_params.rb
index <HASH>..<HASH> 100644
--- a/lib/active_scaffold/attribute_params.rb
+++ b/lib/active_scaffold/attribute_params.rb
@@ -124,7 +124,7 @@ module ActiveScaffold
if parent_record.new_record?
parent_record.cla... | Fix for associations with different class and association names | activescaffold_active_scaffold | train |
fde3b1f4671c5d5817f82d9774ddfa4e1622ebf8 | diff --git a/resources/views/bread/read.blade.php b/resources/views/bread/read.blade.php
index <HASH>..<HASH> 100644
--- a/resources/views/bread/read.blade.php
+++ b/resources/views/bread/read.blade.php
@@ -106,13 +106,13 @@
@elseif($row->type == 'file')
@if... | Replace static storage path with dynamic generated one in read view (BREAD) (#<I>)
* Replace static storage path with dynamic generated one | the-control-group_voyager | train |
09aa3395455981deb9900d49aba8c4ff3dbf267e | diff --git a/actor-apps/app-web/src/app/components/activity/GroupMember.react.js b/actor-apps/app-web/src/app/components/activity/GroupMember.react.js
index <HASH>..<HASH> 100644
--- a/actor-apps/app-web/src/app/components/activity/GroupMember.react.js
+++ b/actor-apps/app-web/src/app/components/activity/GroupMember.re... | fix(web): add listener for kick link only when it need | actorapp_actor-platform | train |
44abbda26e6d2d51021ad49766429b020c053151 | diff --git a/src/Formatter/CurrencyFormatterInterface.php b/src/Formatter/CurrencyFormatterInterface.php
index <HASH>..<HASH> 100644
--- a/src/Formatter/CurrencyFormatterInterface.php
+++ b/src/Formatter/CurrencyFormatterInterface.php
@@ -9,7 +9,7 @@ interface CurrencyFormatterInterface
*
* Supported option... | Improve formatter param/return docs. | commerceguys_intl | train |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
--- a/testing/redis.go
+++ b/testing/redis.go
@@ -19,8 +19,8 @@ const (
CmdDo
)
-// Command is a command sent to the redis server.
-type Command struct {
+// RedisCommand is a command sent to the redis server.
+type RedisCommand struct {
... | testing: use RedisCommand instead of Command for type name | tsuru_tsuru | train |
8bd7ce42e81a5c015eeb29a6aa98383abab54835 | diff --git a/spec/mongoid/tree/ordering_spec.rb b/spec/mongoid/tree/ordering_spec.rb
index <HASH>..<HASH> 100644